from settings import *


class Button:
    def __init__(
        self,
        text: str,
        center: tuple[int, int] = (WIDTH // 2, HEIGHT // 2),
        font: pg.font.Font = pg.font.SysFont("verdana", 32),
        color="lightgray",
        hover_background="black",
    ) -> None:
        """Initialize a new button

        Args:
            text : Text to show on button.
            center : Coordinates of center of the button. Defaults to center of screen).
            font : Font for the text on the button. Defaults to pg.font.SysFont("verdana", 32).
            color : Color of the text on the button. Defaults to light gray.
        """
        self.text = text
        self.font = font
        self.image = self.font.render(self.text, True, color)
        self.image_rect = self.image.get_rect(center=center)
        self.rect = self.image.get_rect(center=center).inflate(25, 25)
        self.rect_surf = pg.Surface((self.rect.w, self.rect.h))
        self.rect_surf.fill(hover_background)
        self.rect_surf.set_alpha(100)
        self.hovering = False
        self.pressed = False
        self.unpressed = False

    def hover(self) -> None:
        """Handles the mouse hovering over the button"""
        if self.rect.collidepoint(pg.mouse.get_pos()):
            self.hovering = True
            self.unpressed = False
            screen.blit(self.rect_surf, self.rect.topleft)
            if any(pg.mouse.get_pressed()):
                self.pressed = True
            else:
                if self.pressed:
                    self.unpressed = True
                self.pressed = False
        else:
            self.hovering = False
            self.pressed = False
            self.unpressed = False

    def draw(self) -> None:
        """Draws the text of the button"""
        screen.blit(self.image, self.image_rect.topleft)

    def update(self) -> None:
        """Update the button"""
        self.hover()
        self.draw()



from settings import *
import webbrowser


class Link:
    def __init__(
        self,
        text,
        link,
        center=(WIDTH / 2, HEIGHT / 2),
        font=pg.font.SysFont("verdana", 32),
        highlighted_font=pg.font.SysFont("verdana", 32),
        color="white",
        highlight_color="lightblue",
    ):
        self.text = text
        self.link = link
        self.center = center
        self.font = font
        self.highlighted_font = highlighted_font
        self.highlighted_font.set_underline(True)
        self.color = color
        self.highlight_color = highlight_color

        self.image = self.font.render(self.text, True, self.color)
        self.highlighted_image = self.highlighted_font.render(
            self.text, True, self.highlight_color
        )
        self.rect = self.image.get_rect(center=self.center)

        self.hovering = False
        self.pressed = False
        self.unpressed = False

    def draw(self):
        if self.rect.collidepoint(pg.mouse.get_pos()):
            self.hovering = True
            screen.blit(self.highlighted_image, self.rect.topleft)
            if any(pg.mouse.get_pressed()):
                self.pressed = True
                self.unpressed = False
            else:
                if self.pressed:
                    self.unpressed = True
                else:
                    self.unpressed = False
                self.pressed = False
        else:
            screen.blit(self.image, self.rect.topleft)
            if self.pressed:
                self.unpressed = True
            else:
                self.unpressed = False
            self.pressed = False
            self.hovering = False

    def update(self):
        self.draw()
        if self.unpressed:
            webbrowser.open(self.link)
